@@ -1,3 +1,3 @@
 from .petit_ts import Type, TSTypeStore, pseudo_classes
 from .base_handler import ClassHandler, BasicHandler, BaseHandler
-from .named_types import NamedLiteral, NamedUnion
\ No newline at end of file
+from .named_types import Named
\ No newline at end of file
